@@ -79,7 +79,7 @@ class Lot(ModelSQL, ModelView, LotMixin, StockMixin):
         'get_quantity', searcher='search_quantity')
     default_uom = fields.Function(
         fields.Many2One('product.uom', "Default UOM"),
-        'on_change_with_default_uom')
+        'on_change_with_default_uom', searcher='search_default_uom')
     default_uom_digits = fields.Function(fields.Integer("Default Unit Digits"),
         'on_change_with_default_uom_digits')
 
@@ -108,6 +108,11 @@ class Lot(ModelSQL, ModelView, LotMixin, StockMixin):
         if self.product:
             return self.product.default_uom.id
 
+    @classmethod
+    def search_default_uom(cls, name, clause):
+        nested = clause[0][len(name):]
+        return [('product.' + name + nested, *clause[1:])]
+
     @fields.depends('product')
     def on_change_with_default_uom_digits(self, name=None):
         if self.product:
@@ -290,8 +295,7 @@ class Move(metaclass=PoolMeta):
 
     def check_lot(self):
         "Check if lot is required"
-        if (self.state == 'done'
-                and self.internal_quantity
+        if (self.internal_quantity
                 and not self.lot
                 and self.product.lot_is_required(
                     self.from_location, self.to_location)):
@@ -300,8 +304,9 @@ class Move(metaclass=PoolMeta):
                     product=self.product.rec_name))
 
     @classmethod
-    def validate(cls, moves):
-        super(Move, cls).validate(moves)
+    @ModelView.button
+    def do(cls, moves):
+        super().do(moves)
         for move in moves:
             move.check_lot()
 
